@@ -10,14 +10,16 @@
 #' @param text character vector
 #' @param fg foreground colour, defaults to white
 #' @param bg background colour, defaults to transparent
+#' @export
 #' @examples
 #' print(colourise("Red", "red"))
 #' cat(colourise("Red", "red"), "\n")
 #' cat(colourise("White on red", "white", "red"), "\n")
 colourise <- function(text, fg = "black", bg = NULL) {
   term <- Sys.getenv()["TERM"]
+  colour_terms <- c("xterm-color", "screen")
   
-  if (is.na(term) || term != "xterm-color") {
+  if (!any(term %in% colour_terms, na.rm = TRUE)) {
     return(text)
   }
   
@@ -35,7 +37,6 @@ colourise <- function(text, fg = "black", bg = NULL) {
   paste(init, text, reset, sep = "")
 }
 
-           
 .fg_colours <- c(
   "black" = "0;30",
   "blue" = "0;34",
@@ -64,4 +65,4 @@ colourise <- function(text, fg = "black", bg = NULL) {
   "purple" = "45",
   "cyan" = "46",
   "light gray" = "47"
-)
\ No newline at end of file
+)
