@@ -9,6 +9,7 @@
 #'  \item \code{\link{is_false}}: falsehood
 #'  \item \code{\link{is_a}}: inheritance
 #'  \item \code{\link{equals}}: equality with numerical tolerance
+#'  \item \code{\link{is_equivalent_to}}: equality ignoring attributes
 #'  \item \code{\link{is_identical_to}}: exact identity
 #'  \item \code{\link{matches}}: string matching
 #'  \item \code{\link{prints_text}}: output matching
@@ -22,17 +23,23 @@
 #' @param object object to test
 #' @param condition, a function that returns whether or not the condition
 #'   is met, and if not, an error message to display.
+#' @param info extra information to be included in the message (useful when
+#'   writing tests in loops)
+#' @export
 #' @examples
 #' expect_that(5 * 2, equals(10))
 #' expect_that(sqrt(2) ^ 2, equals(2))
 #' \dontrun{
 #' expect_that(sqrt(2) ^ 2, is_identical_to(2))
 #' }
-expect_that <- function(object, condition) {
-  name <- deparse(substitute(object))
+expect_that <- function(object, condition, info = NULL) {
+  name <- paste(deparse(substitute(object), width = 500), collapse = "\n")
   results <- condition(object)
   
   results$message <- paste(name, results$message)
+  if (!is.null(info)) {
+    results$message <- paste(results$message, "\n", info, sep = "")
+  }
   
   test_reporter()$add_result(results)
   invisible()
